@@ -1,7 +1,7 @@
 package Bencher::Scenario::DataCleansing::Startup;
 
-our $DATE = '2017-01-15'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2017-01-25'; # DATE
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -44,7 +44,7 @@ Bencher::Scenario::DataCleansing::Startup - Benchmark startup of various data cl
 
 =head1 VERSION
 
-This document describes version 0.002 of Bencher::Scenario::DataCleansing::Startup (from Perl distribution Bencher-Scenarios-DataCleansing), released on 2017-01-15.
+This document describes version 0.003 of Bencher::Scenario::DataCleansing::Startup (from Perl distribution Bencher-Scenarios-DataCleansing), released on 2017-01-25.
 
 =head1 SYNOPSIS
 
@@ -74,7 +74,7 @@ L<Data::Rmap> 0.64
 
 L<Data::Visitor::Callback> 0.30
 
-L<JSON::MaybeXS> 1.003007
+L<JSON::MaybeXS> 1.003005
 
 L<JSON::PP> 2.27300
 
@@ -142,25 +142,25 @@ L<Data::Visitor::Callback>
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.24.0 >>, CPU: I<< Intel(R) Core(TM) i7-4770 CPU @ 3.40GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.5 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
+Run on: perl: I<< v5.24.0 >>, CPU: I<< Intel(R) Core(TM) M-5Y71 CPU @ 1.20GHz (2 cores) >>, OS: I<< GNU/Linux LinuxMint version 17.3 >>, OS kernel: I<< Linux version 3.19.0-32-generic >>.
 
 Benchmark with default options (C<< bencher -m DataCleansing::Startup >>):
 
  #table1#
- +-------------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+-----------+---------+
- | participant             | proc_private_dirty_size (MB) | proc_rss_size (MB) | proc_size (MB) | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors   | samples |
- +-------------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+-----------+---------+
- | Data::Visitor::Callback | 0.82                         | 4.1                | 20             |    120    |                 117.43 |        1   |   0.00027 |      20 |
- | JSON::PP                | 1.3                          | 4.8                | 24             |     15    |                  12.43 |        7.8 | 2.3e-05   |      20 |
- | JSON::MaybeXS           | 3.1                          | 6.7                | 26             |     11    |                   8.43 |       11   | 3.6e-05   |      20 |
- | Data::Abridge           | 16                           | 19                 | 59             |      9.6  |                   7.03 |       13   | 2.7e-05   |      20 |
- | Data::Rmap              | 1.7                          | 5.1                | 23             |      7.7  |                   5.13 |       16   | 1.2e-05   |      20 |
- | JSON::XS                | 1.3                          | 4.7                | 24             |      7.5  |                   4.93 |       16   |   2e-05   |      21 |
- | Cpanel::JSON::XS        | 1.4                          | 4.8                | 23             |      7.1  |                   4.53 |       17   | 1.5e-05   |      20 |
- | Data::Clean::JSON       | 1.9                          | 5.4                | 27             |      6.4  |                   3.83 |       19   | 2.2e-05   |      20 |
- | Data::Clean             | 1.3                          | 4.7                | 20             |      5.2  |                   2.63 |       23   | 1.3e-05   |      20 |
- | perl -e1 (baseline)     | 1.09                         | 4.48               | 20.1           |      2.57 |                   0    |       46.7 | 1.8e-06   |      20 |
- +-------------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+-----------+---------+
+ +-------------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+----------+---------+
+ | participant             | proc_private_dirty_size (MB) | proc_rss_size (MB) | proc_size (MB) | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors  | samples |
+ +-------------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+----------+---------+
+ | Data::Visitor::Callback | 0.82                         | 4.1                | 16             |     170   |                  164.1 |        1   |   0.0004 |      20 |
+ | JSON::PP                | 1.3                          | 4.7                | 20             |      23   |                   17.1 |        7.4 |   6e-05  |      20 |
+ | JSON::MaybeXS           | 3.1                          | 6.6                | 22             |      17   |                   11.1 |        9.8 | 8.2e-05  |      20 |
+ | Data::Abridge           | 16                           | 19                 | 55             |      16   |                   10.1 |       11   | 5.9e-05  |      20 |
+ | Data::Rmap              | 1.7                          | 5.2                | 19             |      13   |                    7.1 |       13   | 7.8e-05  |      20 |
+ | JSON::XS                | 1.3                          | 4.7                | 20             |      13   |                    7.1 |       14   | 5.3e-05  |      20 |
+ | Cpanel::JSON::XS        | 1.4                          | 4.8                | 19             |      12   |                    6.1 |       14   | 4.6e-05  |      20 |
+ | Data::Clean::JSON       | 1.9                          | 5.5                | 23             |      12   |                    6.1 |       15   | 2.9e-05  |      20 |
+ | Data::Clean             | 1.3                          | 4.7                | 16             |      10   |                    4.1 |       17   | 5.9e-05  |      20 |
+ | perl -e1 (baseline)     | 1.1                          | 4.5                | 16             |       5.9 |                    0   |       29   | 1.3e-05  |      20 |
+ +-------------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+----------+---------+
 
 
 To display as an interactive HTML table on a browser, you can add option C<--format html+datatables>.
